summaryrefslogtreecommitdiff
path: root/diag/run_le.sh
diff options
context:
space:
mode:
Diffstat (limited to 'diag/run_le.sh')
-rw-r--r--diag/run_le.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/diag/run_le.sh b/diag/run_le.sh
index 8fc31ea..07d6a63 100644
--- a/diag/run_le.sh
+++ b/diag/run_le.sh
@@ -1,5 +1,5 @@
#!/usr/bin/env bash
# Step-2(iii): TRM-ish GIN full-recursion vs 1-step-gradient, then LE diagnostic on each.
set -uo pipefail
cd /home/yurenh2/rrog
export PYTHONPATH=/home/yurenh2/rrog
@@ -7,6 +7,6 @@ echo "host=$(hostname) gpu=${CUDA_VISIBLE_DEVICES:-?} start=$(date -Is)"
python3 diag/train_rec.py --grad_mode full --sigma 0 --K 1 --epochs 200 --seed 0 || echo "!! train full failed"
python3 diag/train_rec.py --grad_mode 1step --sigma 0 --K 1 --epochs 200 --seed 0 || echo "!! train 1step failed"
echo "===== LE diagnostic (lambda1: success vs failure) ====="
-python3 diag/lyap.py --ckpt runs/ckpt_rec_full_sig0.0_K1_bestq_T3_ns3_s0.pt --n_graphs 300 || echo "!! lyap full failed"
-python3 diag/lyap.py --ckpt runs/ckpt_rec_1step_sig0.0_K1_bestq_T3_ns3_s0.pt --n_graphs 300 || echo "!! lyap 1step failed"
+python3 diag/lyap.py --ckpt runs/ckpt_rec_rrog_full_sig0.0_K1_bestq_T3_ns3_s0.pt --n_graphs 300 || echo "!! lyap full failed"
+python3 diag/lyap.py --ckpt runs/ckpt_rec_rrog_1step_sig0.0_K1_bestq_T3_ns3_s0.pt --n_graphs 300 || echo "!! lyap 1step failed"
echo "done=$(date -Is)"
@@ -1,5 +1,5 @@
#!/usr/bin/env bash
-# Step-2(iii): TRM-ish GIN full-recursion vs 1-step-gradient, then LE diagnostic on each.
+# RRoG/TRM-on-GNN GIN full-recursion vs 1-step-gradient, then LE diagnostic on each.
set -uo pipefail
cd /home/yurenh2/rrog